@@ -3,7 +3,7 @@ ldapobject.py - wraps class _ldap.LDAPObject
 
 See http://www.python-ldap.org/ for details.
 
-\$Id: ldapobject.py,v 1.159 2017/04/24 08:25:16 stroeder Exp $
+\$Id: ldapobject.py,v 1.160 2017/04/25 13:40:52 stroeder Exp $
 
 Compability:
 - Tested with Python 2.0+ but should work with Python 1.5.x
@@ -18,6 +18,8 @@ Basically calls into the LDAP lib are serialized by the module-wide
 lock self._ldap_object_lock.
 """
 
+from os import strerror
+
 from ldap import __version__
 
 __all__ = [
@@ -110,6 +112,8 @@ class SimpleLDAPObject:
       finally:
         self._ldap_object_lock.release()
     except LDAPError,e:
+      if 'info' not in e.args[0]:
+        e.args[0]['info'] = strerror(e.args[0]['errno'])
       if __debug__ and self._trace_level>=2:
         self._trace_file.write('=> LDAPError - %s: %s\n' % (e.__class__.__name__,str(e)))
       raise
